from micro_toolkit.data_process.text_sequence_padding import TextSequencePadding

SequencePadding = TextSequencePadding
